@@ -206,10 +206,9 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/change_password_available').with(:value => nil)
+          is_expected.to contain_tempest_config('compute/change_password_available').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
@@ -218,6 +217,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
           is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
+          is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v3')
@@ -233,10 +233,10 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
-          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => false)
+          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
@@ -269,9 +269,22 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
+          is_expected.to contain_tempest_config('enforce_scope/cinder').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/glance').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/keystone').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity-feature-enabled/enforce_scope').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/neutron').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/nova').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/member_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/admin_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/observer_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/global_observer_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/test_with_noop').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
-          is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
+          is_expected.to contain_oslo__concurrency('tempest_config').with(
+            :lock_path => '/var/lib/tempest'
+          )
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/var/lib/tempest/cirros-0.4.0-x86_64-disk.img')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
           is_expected.to contain_oslo__log('tempest_config').with(
@@ -317,7 +330,7 @@ describe 'tempest' do
       end
     end
 
-    context 'with deprecated img_dir parameter and img_file set' do
+    context 'with img_file set' do
       let :params do
         { :image_name     => 'cirros',
           :image_name_alt => 'cirros' ,
@@ -329,31 +342,6 @@ describe 'tempest' do
       end
     end
 
-    context 'with deprecated img_dir parameter set' do
-      let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros',
-          :img_dir        => '/home/stack' }
-      end
-
-      it 'sets image_file based on img_dir' do
-        is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/home/stack/cirros-0.4.0-x86_64-disk.img')
-      end
-    end
-
-    context 'with deprecated img_dir parameter and img_file set' do
-      let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros',
-          :img_dir        => '/home/stack',
-          :img_file       => 'myimage.img' }
-      end
-
-      it 'sets image_file based on img_dir and img_file' do
-        is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/home/stack/myimage.img')
-      end
-    end
-
     context 'install Tempest from package' do
       let :params do
         {:install_from_source => false,
@@ -392,6 +380,35 @@ describe 'tempest' do
        )
       end
     end
+
+    context 'with flavor_name parameters' do
+      let :params do
+        {
+          :configure_images => false,
+          :flavor_name      => 'm1.tiny',
+          :flavor_name_alt  => 'm1.nano',
+          :db_flavor_name   => 'm1.micro',
+        }
+      end
+
+      it "sets flavor id using setter" do
+        is_expected.to contain_tempest_flavor_id_setter('flavor_ref').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.tiny',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('flavor_ref_alt').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.nano',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('db_flavor_ref').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.micro',
+        )
+      end
+    end
   end
 
   shared_examples 'tempest with plugins packages' do
